{-  
 *  Programmer:	Piotr Borek
 *  E-mail:     piotrborek@op.pl
 *  Copyright 2014 Piotr Borek
 *
 *  Distributed under the terms of the GPL (GNU Public License)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-}

module Mp.Utils.Utils where

import Graphics.Vty
import Control.Monad

toVtyColor :: String -> (Color, Style)
toVtyColor color = case color of
    "black"         -> (black,   dim)
    "white"         -> (white,   dim)
    "cyan"          -> (cyan,    dim)
    "magenta"       -> (magenta, dim)
    "blue"          -> (blue,    dim)
    "yellow"        -> (yellow,  dim)
    "green"         -> (green,   dim)
    "red"           -> (red,     dim)
    "brightBlack"   -> (black,   bold)
    "brightYellow"  -> (yellow,  bold)
    "brightGreen"   -> (green,   bold)
    "brightRed"     -> (red,     bold)
    "brightBlue"    -> (blue,    bold)
    "brightWhite"   -> (white,   bold)
    "brightCyan"    -> (cyan,    bold)
    "brightMagenta" -> (magenta, bold)
    _               -> (black,   dim)

whenM :: Monad m => m Bool -> m () -> m ()
whenM cond action = do
    b <- cond
    when b action

timeToString :: Integer -> String
timeToString time =
    let h  = time `div` 3600
        m  = show $ (time `div` 60) `mod` 60
        m' = if (length m < 2) then "0" ++ m
             else m
        s  = show $ time `mod` 60
        s' = if (length s < 2) then "0" ++ s
             else s
    in
        if h == 0 then m ++ ":" ++ s'
        else (show h) ++ ":" ++ m' ++ ":" ++ s'

separateFilePath :: String -> (String, String)
separateFilePath file =
    let (f, d) = span (/= '/') $ reverse file
    in ((reverse $ tail d), (reverse f))

removeAt :: Int -> [a] -> [a]
removeAt index list = take index list ++ drop (succ index) list
